News for hackers. Stuff that matters.
Re:FastPhotoStyle from Nvidia by JackFr on Wednesday February 21, 2018 @12:41AM (#16427147)
What would you expect the outcome to be?

What is the correct answer to a question that's not well-formed?

Re:FastPhotoStyle from Nvidia by semi-extrinsic on Wednesday February 21, 2018 @01:18AM (#16427284)
The interesting question, then, is how far off can this be and still work? Is the limit "reasonable", or is there room for improvement of the algorithm?

E.g. I think most humans would say taking this content picture:

https://wallpapershome.com/images/pages/pic_hs/10150.jpg

and styling it with this picture:

https://c2.staticflickr.com/4/3499/3876547311_c2e32759d9_z.j...

is a pretty well-posed operation. How does that look using this algorithm?

Re:FastPhotoStyle from Nvidia by IanCal on Wednesday February 21, 2018 @02:42AM (#16427668)
Your first link just redirects to their homepage for me, can you explain which picture it was?
Re:FastPhotoStyle from Nvidia by yorwba on Wednesday February 21, 2018 @04:38AM (#16428165)
It shows a red crab on a beach in front of the bright blue ocean with a blue sky and white clouds.

I guess transfer of the wooden house amidst yellow fields with a reddening sky might lead to a wooden crab on a yellow field in front of a reddish-yellow ocean with red sky and clouds, or something.

Re:FastPhotoStyle from Nvidia by yorwba on Wednesday February 21, 2018 @06:54AM (#16428765)
It actually looks better than expected: https://imgur.com/a/5BjvC
Re:FastPhotoStyle from Nvidia by IanCal on Wednesday February 21, 2018 @07:26AM (#16428919)
Looks nice!

Did you have to do anything extra to get it working? I've set things up according to the documentation (I think), but I get dimension size errors when running it.

Re:FastPhotoStyle from Nvidia by yorwba on Wednesday February 21, 2018 @07:35AM (#16428969)
Haha, yes, I had to rewrite their code a bit. All the .unsqueeze(1).expand_as(...) in photo_wct.py need to be replaced by just .expand_as(...) and the return value of __feature_wct needs to be wrapped in torch.autograd.Variable.

I'm going to submit a PR, but it took me a bit of experimentation to fix these errors, so the code is a bit messier than I'd like.

Re:FastPhotoStyle from Nvidia by IanCal on Wednesday February 21, 2018 @07:47AM (#16429032)
Ahh that looks like the error I was hitting, thanks. I might try replacing the bits as well, though I just upgraded pytorch from 0.1.12 to 0.3 and it became much slower (I killed it after 5-6 minutes of setup).
Re:FastPhotoStyle from Nvidia by yorwba on Wednesday February 21, 2018 @08:33AM (#16429296)
My fork is here: https://github.com/Yorwba/FastPhotoStyle

I was using the pytorch 0.1.12 installed with conda (following their USAGE.md) and it took ~30s total for the transfer.

Re:FastPhotoStyle from Nvidia by IanCal on Wednesday February 21, 2018 @09:06AM (#16429494)
Much appreciated thanks!

For some reason it's taking me about 4-5 minutes for the transfer, but the code now runs and the rest of the runtime is only a few seconds.

Re:FastPhotoStyle from Nvidia by semi-extrinsic on Wednesday February 21, 2018 @02:31PM (#16432222)
Wow, thats pretty good! So this thing can do fairly well on complex transfers.